@@ -1,11 +1,12 @@
+#include <stdlib.h> // If GNU libc, this includes feature.h and defines __USE_GNU
 #include "common.h"
-
-#ifdef __USE_GNU
+#ifdef __USE_GNU // Defined if _GNU_SOURCE is defined and GNU libc is used.
 extern char *program_invocation_short_name;
 #else
 char *program_invocation_short_name;
 #endif
 
+/* Do not inline it so we can set a breakpoint when debugging. */
 void fatal_error(const char *format,...)
 {
     va_list ap;
@@ -13,6 +14,7 @@ void fatal_error(const char *format,...)
     va_start(ap,format);
     vfprintf(stderr, format, ap);
     va_end(ap);
+    fprintf(stderr, "\n");
     exit(EXIT_FAILURE);
 }
 
