@@ -61,8 +61,7 @@ static void usage(void)
            program_invocation_short_name, program_invocation_short_name);
 
     printf(
-"Obtain information and perform some operations on the nondominated sets "
-"given as input. \n\n"
+"Check dominance, filter and transform the sets given as input.\n\n"
 
 "Options:\n"
 OPTION_HELP_STR
@@ -203,27 +202,21 @@ force_bounds (double *points, int nobj, int *cumsizes, int nsets,
 }
 
 static bool
-check_nondominated (const char * filename, const double *points,
-                    int nobj, const int *cumsizes, int nruns,
-                    const signed char *minmax, const signed char agree,
-                    bool **nondom_p)
+check_dominated(const char * filename, const double *points,
+                 int nobj, const int *cumsizes, int nruns,
+                 const signed char *minmax, const signed char agree,
+                 bool * restrict nondom)
 {
-    bool *nondom = nondom_p ? *nondom_p : NULL;
-    bool free_nondom = false;
-    if (nondom == NULL) {
-        free_nondom = true;
-        nondom = nondom_init (cumsizes[nruns - 1]);
-    }
-
     bool first_time = true;
     bool dominated_found = false;
     int filename_len = (int) MAX(strlen(filename), strlen("filename"));
     for (int n = 0, cumsize = 0; n < nruns; cumsize = cumsizes[n], n++) {
         size_t old_size = cumsizes[n] - cumsize;
-        size_t new_size
-            = find_nondominated_set_agree (&points[nobj * cumsize], nobj,
-                                           old_size, minmax, agree,
-                                           &nondom[cumsize]);
+        size_t new_size = (nondom == NULL)
+            ? find_dominated_point_agree(&points[nobj * cumsize], nobj, old_size, minmax, agree)
+            : find_nondominated_set_agree(&points[nobj * cumsize], nobj,
+                                          old_size, minmax, agree,
+                                          &nondom[cumsize]);
 
         if (verbose_flag >= 2) {
             if (first_time) {
@@ -250,12 +243,6 @@ check_nondominated (const char * filename, const double *points,
                          __FILE__, __LINE__);
         }
     }
-
-    if (nondom_p)
-        *nondom_p = nondom;
-    else if (free_nondom)
-        free(nondom);
-
     return dominated_found;
 }
 
@@ -334,7 +321,6 @@ process_file (const char *filename,
               bool check_minimum, bool check_maximum, bool maximise_all_flag,
               const bool *logarithm)
 {
-    bool *nondom = NULL;
     bool logarithm_flag = false;
 
     double *points = NULL;
@@ -344,6 +330,8 @@ process_file (const char *filename,
 
     handle_read_data_error(
         read_double_data (filename, &points, &nobj, &cumsizes, &nsets), filename);
+    ASSUME(nobj > 1 && nobj < 128);
+
     if (!filename)
         filename = stdin_name;
 
@@ -355,13 +343,13 @@ process_file (const char *filename,
     /* Default minmax if not set yet.  */
     bool free_minmax = false;
     if (minmax == NULL) {
-        minmax = maximise_all_flag ? minmax_maximise(nobj) : minmax_minimise(nobj);
+        minmax = maximise_all_flag ? minmax_maximise((dimension_t)nobj) : minmax_minimise((dimension_t)nobj);
         free_minmax = true;
     }
 
     double *minimum = NULL;
     double *maximum = NULL;
-    data_bounds (&minimum, &maximum, points, nobj, cumsizes[nsets - 1]);
+    data_bounds(&minimum, &maximum, points, nobj, cumsizes[nsets - 1]);
 
     if (verbose_flag >= 2)
         print_input_info (stderr, filename, nobj, cumsizes, nsets, minmax,
@@ -423,15 +411,15 @@ process_file (const char *filename,
                    lrange, urange, lbound, ubound);
 
     bool dominated_found = false;
-    /* Check sets.  */
+    // With verbose we print the number of nondominated.
+    bool * nondom = (filter_flag || verbose_flag) ? nondom_init(cumsizes[nsets - 1]) : NULL;
+    // Check sets.
     if (check_flag || filter_flag)
-        dominated_found =
-            check_nondominated (filename, points, nobj, cumsizes, nsets,
-                                minmax, agree, filter_flag ? &nondom : NULL);
+        dominated_found = check_dominated(filename, points, nobj, cumsizes,
+                                          nsets, minmax, agree, nondom);
 
     if (verbose_flag >= 2)
-        fprintf (stderr, "# nondominated: %s\n",
-                 dominated_found ? "FALSE" : "TRUE");
+        fprintf (stderr, "# nondominated: %s\n", bool2str(!dominated_found));
 
     /* Write out nondominated sets.  */
     if (filter_flag || agree || normalise_flag || force_bounds_flag
@@ -466,9 +454,9 @@ process_file (const char *filename,
     free (points);
     free (cumsizes);
     if (free_minmax) free( (void *) minmax);
-    if (nondom) free (nondom);
-    if (log_lbound) free (log_lbound);
-    if (log_ubound) free (log_ubound);
+    if (nondom) free(nondom);
+    if (log_lbound) free(log_lbound);
+    if (log_ubound) free(log_ubound);
 
     *minimum_p = minimum;
     *maximum_p = maximum;
@@ -678,7 +666,7 @@ int main(int argc, char *argv[])
         printf ("# Total maximum:");
         vector_printf (maximum, nobj);
         printf ("\n");
-        printf ("# Nondominated: %s\n", dominated_found ? "FALSE": "TRUE");
+        printf ("# Nondominated: %s\n", bool2str(!dominated_found));
     }
     free(minimum);
     free(maximum);
